@@ -8,7 +8,7 @@ import logging
 import re
 import ssl
 import time
-from collections import Coroutine
+from collections.abc import Coroutine
 from typing import Any, Callable, Dict, Type, List, Optional, TYPE_CHECKING
 from sleekxmpp import ElementBase
 from sleekxmpp.xmlstream import ET
